==> animsition-3.5.2.tgz: package/README.md <==
# [Animsition](http://blivesta.github.io/animsition)

![Bower version](https://img.shields.io/bower/v/animsition.svg?style=flat)
[![npm version](https://img.shields.io/npm/v/animsition.svg?style=flat)](https://www.npmjs.com/package/animsition)
[![Build Status](https://img.shields.io/travis/blivesta/animsition/master.svg?style=flat)](https://travis-ci.org/blivesta/animsition)
[![Dependency Status](https://david-dm.org/blivesta/animsition.svg)](https://david-dm.org/blivesta/animsition)


A simple and easy jQuery plugin for CSS animated page transitions.


## Demo & Installation
http://git.blivesta.com/animsition/


## Development

Install : `nodejs` `npm` `grunt`

```bash
$ git clone https://github.com/blivesta/animsition.git
$ cd animsition
$ git checkout -b patch-1
$ npm install && grunt build && grunt
```

Build
```bash
$ grunt build
```

Watch & Connect
```bash
$ grunt
```

## CDN
[cdnjs](https://cdnjs.com/libraries/animsition)

- css/animsition.css
- css/animsition.min.css
- js/jquery.animsition.js
- js/jquery.animsition.min.js

## Contributing

To contribute to animsition, clone this repo locally and commit your code.  
Please check that everything works before opening a pull-request.


## Contributors
- [@blivesta](https://github.com/blivesta)
- [@munsonbh](https://github.com/munsonbh)
- [@triq6](https://github.com/triq6)
- [@shgtkshruch](https://github.com/shgtkshruch)
- [@gauravpadia](https://github.com/gauravpadia)
- [@ungki](https://github.com/ungki) (Maintainer)
- [@vburlak](https://github.com/vburlak)
- [@wpexplorer](https://github.com/wpexplorer)
- [@armbull](https://github.com/armbull)

## License
Released under the [MIT](https://github.com/blivesta/animsition/blob/master/LICENSE.md) license.


---


## Wordpress plugin

### [Page Transition](http://wordpress.org/plugins/page-transition/ "Page Transition")
- @numixtech
- [@gauravpadia](https://github.com/gauravpadia)
- @asalamwp

==> animsition-3.6.0.tgz: package/README.md <==
# [Animsition](http://blivesta.github.io/animsition)

![Bower version](https://img.shields.io/bower/v/animsition.svg?style=flat-square)
[![npm version](https://img.shields.io/npm/v/animsition.svg?style=flat-square)](https://www.npmjs.com/package/animsition)
[![Build Status](https://img.shields.io/travis/blivesta/animsition/master.svg?style=flat-square)](https://travis-ci.org/blivesta/animsition)


A simple and easy jQuery plugin for CSS animated page transitions.


## Demo & Installation
http://git.blivesta.com/animsition/


## Development

Install : `nodejs` `npm` `gulp`

```bash
$ git clone https://github.com/blivesta/animsition.git
$ cd animsition
$ git checkout -b patch-1
$ npm install && gulp
```

Build
```bash
$ gulp build
```

Build -> Watch
```bash
$ gulp
```

## CDN
[cdnjs](https://cdnjs.com/libraries/animsition)

- css/animsition.css
- css/animsition.min.css
- js/jquery.animsition.js
- js/jquery.animsition.min.js

## Contributing

To contribute to animsition, clone this repo locally and commit your code.  
Please check that everything works before opening a pull-request.


## Contributors
- [@blivesta](https://github.com/blivesta) (Maintainer)
- [@ungki](https://github.com/ungki) (Maintainer)
- [@gauravpadia](https://github.com/gauravpadia) (Maintainer)
- [@munsonbh](https://github.com/munsonbh)
- [@triq6](https://github.com/triq6)
- [@shgtkshruch](https://github.com/shgtkshruch)
- [@vburlak](https://github.com/vburlak)
- [@wpexplorer](https://github.com/wpexplorer)
- [@armbull](https://github.com/armbull)
- [@kkirsche](https://github.com/kkirsche)
- [@justbartlett](https://github.com/justbartlett)
- [@brianmontanaweb](https://github.com/brianmontanaweb)

## License
Released under the [MIT](https://github.com/blivesta/animsition/blob/master/LICENSE.md) license.


---


## Wordpress plugin

### [Page Transition](http://wordpress.org/plugins/page-transition/ "Page Transition")
- @numixtech
- [@gauravpadia](https://github.com/gauravpadia)
- @asalamwp
